@@ -43,7 +43,7 @@ class Chat(Object):
 
         username (``str``, *optional*):
             Username, for private chats, bots, supergroups and channels if available.
-        
+
         first_name (``str``, *optional*):
             First name of the other party in a private chat, for private chats and bots.
 
@@ -109,9 +109,9 @@ class Chat(Object):
         bio (``str``, *optional*):
             Bio of the other party in a private chat.
             Returned only in :meth:`~pyrogram.Client.get_chat`.
-        
+
         join_by_request (``bool``, *optional*):
-            True, if all users directly joining the supergroup need to be approved by supergroup administrators.
+            True, if all users directly joining the supergroup need to be approved by supergroup administrators. Can be True only for non-broadcast supergroups with username, location, or a linked chat.
 
         description (``str``, *optional*):
             Description, for groups, supergroups and channel chats.
@@ -222,7 +222,7 @@ class Chat(Object):
         send_as_chat (:obj:`~pyrogram.types.Chat`, *optional*):
             The default "send_as" chat.
             Returned only in :meth:`~pyrogram.Client.get_chat`.
-        
+
         is_peak_preview (``bool``, *optional*):
             True, if this is a peak preview.
 
@@ -231,7 +231,7 @@ class Chat(Object):
 
         pending_join_request_count (``int``, *optional*):
             Number of pending join requests in the current chat.
-        
+
         can_enable_paid_reaction (``bool``, *optional*):
             True, if paid reaction can be enabled in the channel chat; for channels only.
 
@@ -250,6 +250,7 @@ class Chat(Object):
 
         full_name (``str``, *property*):
             Full name of the other party in a private chat, for private chats and bots.
+            OR, Title of the chat, for groups and channels.
 
     """
 
@@ -645,7 +646,7 @@ class Chat(Object):
                 parsed_chat.birthdate = types.Birthdate._parse(
                     full_user.birthday
                 )
-            
+
             if getattr(full_user, "business_intro", None):
                 parsed_chat.business_intro = await types.BusinessIntro._parse(
                     client,
@@ -810,7 +811,7 @@ class Chat(Object):
                     self.last_name
                 ]
             )
-        ) or None
+        ) or self.title or None
 
     async def archive(self):
         """Bound method *archive* of :obj:`~pyrogram.types.Chat`.
